@@ -33,4 +33,4 @@
 #'
 #' @keywords package
 
-NULL
+"_PACKAGE"
